==> konsole_17.12.3.orig.tar.xz: konsole-17.12.3/src/TabTitleFormatButton.h <==
/*
    Copyright 2007-2008 by Robert Knight <robertknight@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301  USA.
*/

#ifndef TABTITLEFORMATBUTTON_H
#define TABTITLEFORMATBUTTON_H

// Qt
#include <QPushButton>
#include <QAction>

// Konsole
#include "Session.h"

namespace Konsole {
class TabTitleFormatButton : public QPushButton
{
    Q_OBJECT

public:
    explicit TabTitleFormatButton(QWidget *parent);
    ~TabTitleFormatButton() Q_DECL_OVERRIDE;

    void setContext(Session::TabTitleContext context);
    Session::TabTitleContext context() const;

Q_SIGNALS:
    void dynamicElementSelected(const QString &);

private Q_SLOTS:
    void fireElementSelected(QAction *);

private:
    Session::TabTitleContext _context;

    struct Element {
        QString element;
        const char *description;
    };
    static const Element _localElements[];
    static const int _localElementCount;
    static const Element _remoteElements[];
    static const int _remoteElementCount;
};
}

#endif // TABTITLEFORMATBUTTON_H

==> konsole-18.04.0.tar.xz: konsole-18.04.0/src/TabTitleFormatButton.h <==
/*
    Copyright 2007-2008 by Robert Knight <robertknight@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301  USA.
*/

#ifndef TABTITLEFORMATBUTTON_H
#define TABTITLEFORMATBUTTON_H

// Qt
#include <QPushButton>
#include <QAction>

// Konsole
#include "Session.h"

namespace Konsole {
class TabTitleFormatButton : public QPushButton
{
    Q_OBJECT

public:
    explicit TabTitleFormatButton(QWidget *parent);
    ~TabTitleFormatButton() Q_DECL_OVERRIDE;

    void setContext(Session::TabTitleContext titleContext);
    Session::TabTitleContext context() const;

Q_SIGNALS:
    void dynamicElementSelected(const QString &);

private Q_SLOTS:
    void fireElementSelected(QAction *);

private:
    Session::TabTitleContext _context;

    struct Element {
        QString element;
        const char *description;
    };
    static const Element _localElements[];
    static const int _localElementCount;
    static const Element _remoteElements[];
    static const int _remoteElementCount;
};
}

#endif // TABTITLEFORMATBUTTON_H
